==> okta-sdk-api-19.0.1-sources.jar: com/okta/sdk/resource/model/CsrMetadataSubjectAltNames.java <==
package com.okta.sdk.resource.model;

import java.util.Objects;
import java.util.Arrays;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonTypeName;
import com.fasterxml.jackson.annotation.JsonValue;
import java.util.ArrayList;
import java.util.Arrays;
import java.util.List;
import java.io.Serializable;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.fasterxml.jackson.annotation.JsonTypeName;
import io.swagger.annotations.ApiModelProperty;
import io.swagger.annotations.ApiModel;

/**
 * CsrMetadataSubjectAltNames
 */
@JsonPropertyOrder({ CsrMetadataSubjectAltNames.JSON_PROPERTY_DNS_NAMES })
@javax.annotation.Generated(value = "org.openapitools.codegen.languages.JavaClientCodegen", date = "2024-10-04T18:50:18.667445-05:00[America/Chicago]", comments = "Generator version: 7.8.0")
public class CsrMetadataSubjectAltNames implements Serializable {

    private static final long serialVersionUID = 1L;

    public static final String JSON_PROPERTY_DNS_NAMES = "dnsNames";
    private List<String> dnsNames = null;

    public CsrMetadataSubjectAltNames() {
    }

    public CsrMetadataSubjectAltNames dnsNames(List<String> dnsNames) {

        this.dnsNames = dnsNames;
        return this;
    }

    public CsrMetadataSubjectAltNames adddnsNamesItem(String dnsNamesItem) {
        if (this.dnsNames == null) {
            this.dnsNames = new ArrayList<>();
        }
        this.dnsNames.add(dnsNamesItem);
        return this;
    }

    /**
     * DNS names of the subject
     *
     * @return dnsNames
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "DNS names of the subject")
    @JsonProperty(JSON_PROPERTY_DNS_NAMES)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public List<String> getDnsNames() {
        return dnsNames;
    }

    @JsonProperty(JSON_PROPERTY_DNS_NAMES)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setDnsNames(List<String> dnsNames) {
        this.dnsNames = dnsNames;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (o == null || getClass() != o.getClass()) {
            return false;
        }
        CsrMetadataSubjectAltNames csrMetadataSubjectAltNames = (CsrMetadataSubjectAltNames) o;
        return Objects.equals(this.dnsNames, csrMetadataSubjectAltNames.dnsNames);
        // ;
    }

    @Override
    public int hashCode() {
        return Objects.hash(dnsNames);
    }

    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("class CsrMetadataSubjectAltNames {\n");
        sb.append("    dnsNames: ").append(toIndentedString(dnsNames)).append("\n");
        sb.append("}");
        return sb.toString();
    }

    /**
     * Convert the given object to string with each line indented by 4 spaces (except the first line).
     */
    private String toIndentedString(Object o) {
        if (o == null) {
            return "null";
        }
        return o.toString().replace("\n", "\n    ");
    }

}

==> okta-sdk-api-23.0.0-sources.jar: com/okta/sdk/resource/model/CsrMetadataSubjectAltNames.java <==
package com.okta.sdk.resource.model;

import java.util.Objects;
import java.util.Arrays;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonTypeName;
import com.fasterxml.jackson.annotation.JsonValue;
import java.util.ArrayList;
import java.util.Arrays;
import java.util.List;
import java.io.Serializable;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.fasterxml.jackson.annotation.JsonTypeName;
import io.swagger.annotations.ApiModelProperty;
import io.swagger.annotations.ApiModel;

/**
 * CsrMetadataSubjectAltNames
 */
@JsonPropertyOrder({ CsrMetadataSubjectAltNames.JSON_PROPERTY_DNS_NAMES })
@jakarta.annotation.Generated(value = "org.openapitools.codegen.languages.JavaClientCodegen", date = "2025-05-05T16:46:15.395194+05:30[Asia/Kolkata]", comments = "Generator version: 7.11.0")
public class CsrMetadataSubjectAltNames implements Serializable {

    private static final long serialVersionUID = 1L;

    public static final String JSON_PROPERTY_DNS_NAMES = "dnsNames";
    private List<String> dnsNames = null;

    public CsrMetadataSubjectAltNames() {
    }

    public CsrMetadataSubjectAltNames dnsNames(List<String> dnsNames) {

        this.dnsNames = dnsNames;
        return this;
    }

    public CsrMetadataSubjectAltNames adddnsNamesItem(String dnsNamesItem) {
        if (this.dnsNames == null) {
            this.dnsNames = new ArrayList<>();
        }
        this.dnsNames.add(dnsNamesItem);
        return this;
    }

    /**
     * DNS names of the subject
     *
     * @return dnsNames
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "DNS names of the subject")
    @JsonProperty(JSON_PROPERTY_DNS_NAMES)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public List<String> getDnsNames() {
        return dnsNames;
    }

    @JsonProperty(JSON_PROPERTY_DNS_NAMES)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setDnsNames(List<String> dnsNames) {
        this.dnsNames = dnsNames;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (o == null || getClass() != o.getClass()) {
            return false;
        }
        CsrMetadataSubjectAltNames csrMetadataSubjectAltNames = (CsrMetadataSubjectAltNames) o;
        return Objects.equals(this.dnsNames, csrMetadataSubjectAltNames.dnsNames);
        // ;
    }

    @Override
    public int hashCode() {
        return Objects.hash(dnsNames);
    }

    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("class CsrMetadataSubjectAltNames {\n");
        sb.append("    dnsNames: ").append(toIndentedString(dnsNames)).append("\n");
        sb.append("}");
        return sb.toString();
    }

    /**
     * Convert the given object to string with each line indented by 4 spaces (except the first line).
     */
    private String toIndentedString(Object o) {
        if (o == null) {
            return "null";
        }
        return o.toString().replace("\n", "\n    ");
    }

}
